"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const helpers_1 = require("./helpers");
const pluralize_1 = __importDefault(require("pluralize"));
function generateModel(component, fields) {
    if (helpers_1.checkLineExistsInFile("src/models/index.ts", component)) {
        return;
    }
    const scriptModel = `import { Column, Entity, PrimaryGeneratedColumn } from "typeorm";

@Entity({ name: "${pluralize_1.default(component)}" })
export class ${helpers_1.firstWordToUppercase(component)} {
  @PrimaryGeneratedColumn("uuid")
  id!: string;

  ${fields && fields.length
        ? fields
            .map(field => {
            if (field.split(":").length > 2) {
                throw new Error("format model wrong.");
            }
            const [nameField, typeField] = field.split(":");
            if (!helpers_1.primitiveTypescript.includes(typeField)) {
                throw new Error("Type primitive invalid for typeorm");
            }
            return `@Column()
  ${nameField}!: ${typeField};
`;
        })
            .join("\n  ")
        : ""}}
`;
    fs_1.writeFileSync(`src/models/${helpers_1.firstWordToUppercase(component)}.ts`, scriptModel);
    fs_1.appendFileSync("src/models/index.ts", `export * from "./${helpers_1.firstWordToUppercase(component)}";\n`);
}
exports.generateModel = generateModel;
