"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const helpers_1 = require("./helpers");
function generateSdkgen(component, functions) {
    if (helpers_1.checkLineExistsInFile("src/api.sdkgen", component)) {
        return;
    }
    const contentFile = functions && functions.length
        ? functions
            .map(fun => {
            const [nameFunction, argsFunction] = fun.split("#");
            if (!argsFunction) {
                return `fn ${nameFunction}(): string\n`;
            }
            const args = argsFunction.split(",");
            if (args.length > 1) {
                const argsAndTypes = args
                    .map(arg => {
                    const [nameArg, typeArg] = arg.split(":");
                    if (!helpers_1.primitivesSdkgen.includes(typeArg)) {
                        throw new Error("Type primitive invalid for sdkgen");
                    }
                    return `${nameArg}: ${typeArg}`;
                })
                    .join(", ");
                return `fn ${nameFunction}(${argsAndTypes}): string\n`;
            }
            const [nameArg, typeArg] = args[0].split(":");
            if (!helpers_1.primitivesSdkgen.includes(typeArg)) {
                throw new Error("Type primitive invalid for sdkgen");
            }
            return `fn ${nameFunction}(${nameArg}: ${typeArg}): string\n`;
        })
            .join("")
        : `fn get${helpers_1.firstWordToUppercase(component)}(): string\n`;
    fs_1.writeFileSync(`src/schemas/${component}.sdkgen`, contentFile);
    fs_1.appendFileSync("src/api.sdkgen", `import "./schemas/${component}"\n`);
}
exports.generateSdkgen = generateSdkgen;
